@@ -41,8 +41,6 @@
 
 #define KROSSCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KROSSCORE_NO_DEPRECATED) && !defined(KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KROSSCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KROSSCORE_NO_DEPRECATED
-#  define KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KROSSCORE_NO_DEPRECATED_WARNINGS
 #  define KROSSCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KROSSCORE_DEPRECATED_WARNINGS_SINCE KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KROSSCORE_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KROSSCORE_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KROSSCORE_DEPRECATED
-#  define KROSSCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KROSSCORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KROSSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KROSSCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
